# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`vault_secrets`](#vault_secrets): Issue and renew PKI certificates from Hashicorp Vault
* [`vault_secrets::vault_cert`](#vault_secretsvault_cert): Manage paths and files for Vault certificates

### Defined types

* [`vault_secrets::approle_agent`](#vault_secretsapprole_agent): Configure a Vault agent for use with an existing AppRole and save the
resulting token to a sink file at "/run/vault-${owner}/${title}.token"

### Resource types

* [`vault_cert`](#vault_cert): A type representing a certificate issued by Hashicorp Vault
* [`vault_ssh_cert`](#vault_ssh_cert): A type representing an SSH certificate issued by Hashicorp Vault

### Functions

* [`vault_cert`](#vault_cert): Obtain a host certificate from a Vault PKI secrets engine
* [`vault_hash`](#vault_hash): Return a hash from a Vault key/value secrets engine path
* [`vault_hiera_hash`](#vault_hiera_hash): Custom hiera back-end for Hashicorp Vault key/value secrets engines v1 and v2
* [`vault_key`](#vault_key): Return the value from a Vault key/value secrets engine from a given path and key

### Plans

* [`vault_secrets::approle_agent`](#vault_secretsapprole_agent): Plan configures a Vault agent for use with an existing AppRole

## Classes

### <a name="vault_secrets"></a>`vault_secrets`

Issue and renew PKI certificates from Hashicorp Vault

#### Examples

##### Issue a host certificate from a Vault server with PKI secrets engine

```puppet
class { 'vault_secrets':
  vault_uri  => 'https://vault.example.com:8200/v1/pki/issue/example-com',
  auth_path  => 'puppet-pki',
}
```

#### Parameters

The following parameters are available in the `vault_secrets` class:

* [`vault_uri`](#vault_uri)
* [`auth_path`](#auth_path)
* [`days_before_renewal`](#days_before_renewal)
* [`cert_data`](#cert_data)

##### <a name="vault_uri"></a>`vault_uri`

Data type: `String`

The complete URL of the the Hashicorp Vault certificate issuing role API endpoint

##### <a name="auth_path"></a>`auth_path`

Data type: `String`

The Vault mount path of the authentication provider used by Puppet certificates. ('path' shown by 'vault secrets list')

##### <a name="days_before_renewal"></a>`days_before_renewal`

Data type: `Integer[1, 30]`

The number of days before expiration where the host certificate will be re-issued.

Default value: `3`

##### <a name="cert_data"></a>`cert_data`

Data type: `Hash`

A hash of values to be submitted with the certificate request.  The hash contents should
adhere to the keys/values supported/permitted by the PKI role and policy.  Basic default values are
defined in module hiera.

Default value: `{}`

### <a name="vault_secretsvault_cert"></a>`vault_secrets::vault_cert`

Manage paths and files for Vault certificates

#### Parameters

The following parameters are available in the `vault_secrets::vault_cert` class:

* [`purge`](#purge)

##### <a name="purge"></a>`purge`

Data type: `Any`

Clean up certificate files no longer managed by puppet.

Default value: ``false``

## Defined types

### <a name="vault_secretsapprole_agent"></a>`vault_secrets::approle_agent`

Configure a Vault agent for use with an existing AppRole and save the
resulting token to a sink file at "/run/vault-${owner}/${title}.token"

* **Note** The defined type name permits only alpha-numeric characters and underscores.

* **See also**
  * https://www.vaultproject.io/docs/auth/approle

#### Examples

##### Create a Vault agent for use with vault_hiera_hash

```puppet
vault_secrets::approle_agent { 'puppetserver':
   vault_addr => 'https://vault.example.com:8200',
   role_id    => 'your_roleId_guid',
   secret_id  => 'your_secretId_guid',
   owner      => 'pe-puppet',
 }
```

#### Parameters

The following parameters are available in the `vault_secrets::approle_agent` defined type:

* [`ensure`](#ensure)
* [`vault_addr`](#vault_addr)
* [`role_id`](#role_id)
* [`secret_id`](#secret_id)
* [`owner`](#owner)
* [`install_vault`](#install_vault)

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

Add or remove the Vault agent configuration.

Default value: `'present'`

##### <a name="vault_addr"></a>`vault_addr`

Data type: `String`

The URL of the Vault service.

##### <a name="role_id"></a>`role_id`

Data type: `String`

The RoleID of the Vault AppRole.

##### <a name="secret_id"></a>`secret_id`

Data type: `String`

The SecretID of the Vault AppRole.

##### <a name="owner"></a>`owner`

Data type: `String`

The user name that will own the Vault agent sink file.

##### <a name="install_vault"></a>`install_vault`

Data type: `Boolean`

Install Vault using the "hashi_stack::repo" class.  Use
hiera to set parameters for customizing the installation.

Default value: ``true``

## Resource types

### <a name="vault_cert"></a>`vault_cert`

A type representing a certificate issued by Hashicorp Vault

#### Properties

The following properties are available in the `vault_cert` type.

##### `ca_chain`

Valid values: `auto`

Read-only property which contains the value of the CA chain

Default value: `auto`

##### `ca_chain_file`

Where the CA chain file should be written

##### `ca_chain_group`

The group which the ca_chain_file should be owned by

Default value: `root`

##### `ca_chain_mode`

The file mode the ca_chain_file should be written with

Default value: `0644`

##### `ca_chain_owner`

The user which the ca_chain_file should be owned by

Default value: `root`

##### `cert`

Valid values: `auto`

Read-only property which contains the value of the certificate

Default value: `auto`

##### `cert_data`

The attributes of the certificate to be issued

##### `cert_file`

Where the certificate file should be written

##### `cert_group`

The group which the cert_file should be owned by

Default value: `root`

##### `cert_mode`

The file mode the cert _file should be written with

Default value: `0644`

##### `cert_owner`

The user which the cert_file should be owned by

Default value: `root`

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `expiration`

Valid values: `auto`

Read-only property showing the expiration time of the certificate

Default value: `auto`

##### `info_ca_chain`

Valid values: `auto`

Read-only property which contains the value of the CA chain from the info file

Default value: `auto`

##### `info_cert`

Valid values: `auto`

Read-only property which contains the value of the cerificate from the info file

Default value: `auto`

##### `info_group`

The group which the info_file should be owned by

Default value: `root`

##### `info_key`

Valid values: `auto`

Read-only property which contains the value of the private key from the info file

Default value: `auto`

##### `info_mode`

The file mode the info_file should be written with

Default value: `0600`

##### `info_owner`

The user which the info_file should be owned by

Default value: `root`

##### `key`

Valid values: `auto`

Read-only property which contains the value of the privat ekey

Default value: `auto`

##### `key_file`

Where the key file should be written

##### `key_group`

The group which the key_file should be owned by

Default value: `root`

##### `key_mode`

The file mode the key file should be written with

Default value: `0600`

##### `key_owner`

The user which the key_file should be owned by

Default value: `root`

#### Parameters

The following parameters are available in the `vault_cert` type.

* [`auth_name`](#auth_name)
* [`auth_path`](#auth_path)
* [`name`](#name)
* [`provider`](#provider)
* [`renewal_threshold`](#renewal_threshold)
* [`timeout`](#timeout)
* [`vault_uri`](#vault_uri)

##### <a name="auth_name"></a>`auth_name`

The named certificate role used to authenticate puppet agent to vault

##### <a name="auth_path"></a>`auth_path`

The path used to authenticate puppet agent to vault

Default value: `puppet-pki`

##### <a name="name"></a>`name`

namevar

The name of the certificate

##### <a name="provider"></a>`provider`

The specific backend to use for this `vault_cert` resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.

##### <a name="renewal_threshold"></a>`renewal_threshold`

Certificate should be renewed when fewer than this many days remain before expiry

Default value: `3`

##### <a name="timeout"></a>`timeout`

Length of time to wait on vault connections

Default value: `5`

##### <a name="vault_uri"></a>`vault_uri`

The full URI of the vault PKI secrets engine

### <a name="vault_ssh_cert"></a>`vault_ssh_cert`

A type representing an SSH certificate issued by Hashicorp Vault

#### Properties

The following properties are available in the `vault_ssh_cert` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `expiration`

Valid values: `auto`

Read-only property showing the expiration time of the certificate

Default value: `auto`

##### `file`

Path the signed certificate should be written

##### `group`

The group which the certificate file should be owned by

Default value: `root`

##### `mode`

The file mode the certificate file should be written with

Default value: `0640`

##### `owner`

The user which the certificate file should be owned by

Default value: `root`

##### `valid_principals`

Users or hostnames which the issued certificate should be valid for

Default value: `[]`

#### Parameters

The following parameters are available in the `vault_ssh_cert` type.

* [`auth_name`](#auth_name)
* [`auth_path`](#auth_path)
* [`cert_type`](#cert_type)
* [`name`](#name)
* [`provider`](#provider)
* [`renewal_threshold`](#renewal_threshold)
* [`timeout`](#timeout)
* [`ttl`](#ttl)
* [`vault_uri`](#vault_uri)

##### <a name="auth_name"></a>`auth_name`

The named certificate role used to authenticate puppet agent to vault

##### <a name="auth_path"></a>`auth_path`

The path used to authenticate puppet agent to vault

Default value: `puppet-pki`

##### <a name="cert_type"></a>`cert_type`

Cert type to issue ("user" or "host")

Default value: `host`

##### <a name="name"></a>`name`

namevar

Path to the public key the certificate should be issued for

##### <a name="provider"></a>`provider`

The specific backend to use for this `vault_ssh_cert` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### <a name="renewal_threshold"></a>`renewal_threshold`

Certificate should be renewed when fewer than this many days remain before expiry

Default value: `3`

##### <a name="timeout"></a>`timeout`

Length of time to wait on vault connections

Default value: `5`

##### <a name="ttl"></a>`ttl`

Lifetime to request any newly issued certificates should be valid for

##### <a name="vault_uri"></a>`vault_uri`

The full URI of the vault PKI secrets engine

## Functions

### <a name="vault_cert"></a>`vault_cert`

Type: Ruby 4.x API

Obtain a host certificate from a Vault PKI secrets engine

#### `vault_cert(String $vault_uri, String $auth_path, Hash $data, Optional[Integer] $timeout, Optional[String] $ca_trust)`

Obtain a host certificate from a Vault PKI secrets engine

Returns: `Hash` The returned hash contains the certificate, private key, and supporting data

##### `vault_uri`

Data type: `String`

The complete API path to a Vault PKI role for issuing certificates.

##### `auth_path`

Data type: `String`

The Vault mount path of the "cert" authentication type used with Puppet certificates.

##### `data`

Data type: `Hash`

A hash of values to be submitted with a certificate request.  The hash contents
must adhere to the constructs of the Vault PKI role and policy being used at the 'vault_uri' endpoint.

##### `timeout`

Data type: `Optional[Integer]`

Value in seconds to wait for Vault connections.  Default is 5.

##### `ca_trust`

Data type: `Optional[String]`

The path to the trusted certificate authority chain file.  Some OS defaults will be attempted if nil.

### <a name="vault_hash"></a>`vault_hash`

Type: Ruby 4.x API

Return a hash from a Vault key/value secrets engine path

#### `vault_hash(String $vault_uri, String $auth_path, Optional[String] $version, Optional[Integer] $timeout, Optional[String] $ca_trust)`

Return a hash from a Vault key/value secrets engine path

Returns: `Hash` Contains all the key/value pairs from the given path.

##### `vault_uri`

Data type: `String`

The full URI to the Vault API endpoint for a key/value secrets engine path.

##### `auth_path`

Data type: `String`

The Vault mount path of the 'cert' authentication type used with Puppet certificates.

##### `version`

Data type: `Optional[String]`

Set this value to 'v2' to use version 2 of the Vault key/value secrets engine.

##### `timeout`

Data type: `Optional[Integer]`

Value in seconds to wait for Vault connections.

##### `ca_trust`

Data type: `Optional[String]`

The path to the trusted certificate authority chain file.  Some OS defaults will be attempted if nil.

### <a name="vault_hiera_hash"></a>`vault_hiera_hash`

Type: Ruby 4.x API

Custom hiera back-end for Hashicorp Vault key/value secrets engines v1 and v2

#### `vault_hiera_hash(Hash $options, Puppet::LookupContext $context)`

Custom hiera back-end for Hashicorp Vault key/value secrets engines v1 and v2

Returns: `Hash` All key/value pairs from the given Vault path will be returned to hiera

##### `options`

Data type: `Hash`

uri, ca_trust, token_file, auth_path, version, timeout, fail_hard

Options:

* **:uri** `String`: Required. The complete URL to the API endpoint for Hashicorp Vault key/value secrets.
* **:ca_trust** `String`: Optional path to a trusted CA certificate chain file.  Will try system defaults for RedHat/Debian if not set.
* **:token_file** `String`: The path to a file that contains a Vault token. When not defined it will try PKI auth with Puppet cert.
* **:auth_path** `String`: Optional. The Vault path for the "cert" authentication type used with Puppet certificates.
* **:version** `String`: The Vault key/value secrets engine will always use 'v1' unless set to 'v2' here.
* **:timeout** `Integer`: Optional value for tuning HTTP timeouts. Default is 5 seconds.
* **:fail_hard** `Boolean`: Optional Raise an exception on errors when true, or return an empty hash when false. (false)

##### `context`

Data type: `Puppet::LookupContext`



### <a name="vault_key"></a>`vault_key`

Type: Ruby 4.x API

Return the value from a Vault key/value secrets engine from a given path and key

#### `vault_key(String $vault_uri, String $auth_path, String $key, Optional[String] $version, Optional[Integer] $timeout, Optional[String] $ca_trust)`

Return the value from a Vault key/value secrets engine from a given path and key

Returns: `String` The value of the secret from the @vault_uri and @key

##### `vault_uri`

Data type: `String`

The complete API path to a Vault key/value secret

##### `auth_path`

Data type: `String`

The Vault mount path of the "cert" authentication type used with Puppet certificates.

##### `key`

Data type: `String`

The name of a specific secret at the given 'vault_uri'

##### `version`

Data type: `Optional[String]`

Set this value to 'v2' to use version 2 of the Vault key/value secrets engine

##### `timeout`

Data type: `Optional[Integer]`

Value in seconds to wait for a response from Vault

##### `ca_trust`

Data type: `Optional[String]`

The path to the trusted certificate authority chain file.  Some OS defaults will be attempted if nil.

## Plans

### <a name="vault_secretsapprole_agent"></a>`vault_secrets::approle_agent`

Plan configures a Vault agent for use with an existing AppRole

#### Parameters

The following parameters are available in the `vault_secrets::approle_agent` plan:

* [`action`](#action)
* [`application`](#application)
* [`vault_addr`](#vault_addr)
* [`role_id`](#role_id)
* [`secret_id`](#secret_id)
* [`owner`](#owner)
* [`install_vault`](#install_vault)
* [`targets`](#targets)

##### <a name="action"></a>`action`

Data type: `Enum['install', 'remove']`

Install or remove the specified Vault agent service

Default value: `'install'`

##### <a name="application"></a>`application`

Data type: `String`

Used as a component resource names. The Vault agent sink is: "/run/vault-${owner}/${application}.token"

##### <a name="vault_addr"></a>`vault_addr`

Data type: `String`

The URL of the Vault service.

##### <a name="role_id"></a>`role_id`

Data type: `Sensitive`

String - The RoleID of the Vault AppRole.

##### <a name="secret_id"></a>`secret_id`

Data type: `Sensitive`

String - The SecretID of the Vault AppRole.

##### <a name="owner"></a>`owner`

Data type: `String`

The user name that will own the Vault agent sink file.

##### <a name="install_vault"></a>`install_vault`

Data type: `Boolean`

Install Vault using the "hashi_stack::repo" class.  Set
parameters for "hashi_stack::repo" in hiera to customize the installation.

Default value: ``true``

##### <a name="targets"></a>`targets`

Data type: `TargetSpec`



